==> spip_3.0.8.orig.tar.xz: spip-3.0.8.orig/plugins-dist/statistiques/lang/statistiques_ru.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/statistiques?lang_cible=ru
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_effacer_referers' => 'Удалить информацию о источниках переходов',
	'bouton_effacer_statistiques' => 'Очистить статистику',

	// C
	'csv' => 'csv',

	// I
	'icone_evolution_visites' => 'Количество посещений<br />@visites@ ',
	'icone_repartition_actuelle' => 'На данный момент',
	'icone_repartition_visites' => 'Распределение посещений',
	'icone_statistiques_visites' => 'Статистика посещений',
	'info_affichier_visites_articles_plus_visites' => 'Самые популярные статьи с начала работы сайта: </b>',
	'info_comment_lire_tableau' => 'Пояснения к графику',
	'info_forum_statistiques' => 'Статистика посещений сайта',
	'info_popularite_2' => 'популярность сайта:',
	'info_popularite_3' => 'популярность: @popularite@; посещения: @visites@',
	'info_popularite_5' => 'популярность:',
	'info_previsions' => 'прогноз:',
	'info_question_vignettes_referer' => 'Система может самостоятельно делать скриншоты главных страниц сайтов, с которых к вам приходят посетители. Если вы включите эту опцию, то это изображение будет выводится рядом с ссылкой на этот сайт.',
	'info_question_vignettes_referer_oui' => 'Разрешить формировать скриншоты сайтов',
	'info_visites' => 'посещения:',
	'info_visites_plus_populaires' => 'Показать статистику для <b> самых популярных </b> и <b>последних опубликованных статей:</b>',
	'info_zoom' => 'увеличить',
	'item_gerer_statistiques' => 'Сохранять информацию о посещениях',

	// O
	'onglet_origine_visites' => 'Источники переходов',
	'onglet_repartition_debut' => 'с начала',
	'onglet_repartition_lang' => 'Распределение по языкам',

	// R
	'resume' => 'Сводка',

	// T
	'texte_admin_effacer_stats' => 'Это команда удаляет все данные, которые связаны со статистикой посещений сайта,включая статистику по статьям. ',
	'texte_admin_effacer_toutes_stats' => 'Первая кнопка удаляет всю статистику о: посещениях, популярности и источниках переходов.',
	'texte_comment_lire_tableau' => 'Справа 
 показывается уровень 
  посещаемости статьи; черной линией отображается прогноз посещений (при условии 
 что сохранится 
  текущая динамика), и зеленым цветом - количество посещений за день. 
 Для более подробной информации 
 наведите мышку на интересующую Вас дату. ',
	'texte_signification' => 'Темные штрихи представляют накопленные записи (общее количество подразделов), светлые штрихи, представляют количество посещений для каждого раздела.',
	'titre_evolution_visite' => 'Уровень посещений',
	'titre_liens_entrants' => 'Источники переходов',
	'titre_page_statistiques' => 'Распределение по разделам',
	'titre_page_statistiques_visites' => 'История посещений',

	// V
	'visites_journalieres' => 'Количество посетителей (день)',
	'visites_mensuelles' => 'Количество посетителей (месяц)'
);

?>

==> spip_3.0.11.orig.tar.xz: spip-3.0.11.orig/plugins-dist/statistiques/lang/statistiques_ru.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/statistiques?lang_cible=ru
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_effacer_referers' => 'Удалить информацию о источниках переходов',
	'bouton_effacer_statistiques' => 'Удалить всю статистику',

	// C
	'csv' => 'csv',

	// I
	'icone_evolution_visites' => 'Количество посещений<br />@visites@ ',
	'icone_repartition_actuelle' => 'На данный момент',
	'icone_repartition_visites' => 'По разделам',
	'icone_statistiques_visites' => 'Статистика посещений',
	'info_affichier_visites_articles_plus_visites' => 'Самые популярные статьи с начала работы сайта: </b>',
	'info_comment_lire_tableau' => 'Пояснения к графику',
	'info_forum_statistiques' => 'Статистика посещений сайта',
	'info_popularite_2' => 'популярность сайта:',
	'info_popularite_3' => 'популярность: @popularite@; посещения: @visites@',
	'info_popularite_5' => 'популярность:',
	'info_previsions' => 'прогноз:',
	'info_question_vignettes_referer' => 'Система может самостоятельно делать скриншоты главных страниц сайтов, с которых к вам приходят посетители. Если вы включите эту опцию, то это изображение будет выводится рядом с ссылкой на этот сайт.',
	'info_question_vignettes_referer_oui' => 'Разрешить формировать скриншоты сайтов',
	'info_visites' => 'посещения:',
	'info_visites_plus_populaires' => 'Показать статистику для <b> самых популярных </b> и <b>последних опубликованных статей:</b>',
	'info_zoom' => 'увеличить',
	'item_gerer_statistiques' => 'Сохранять информацию о посещениях',

	// O
	'onglet_origine_visites' => 'Источники переходов',
	'onglet_repartition_debut' => 'с начала',
	'onglet_repartition_lang' => 'По языкам',

	// R
	'resume' => 'Сводка',

	// T
	'texte_admin_effacer_stats' => 'Это команда удаляет все данные, которые связаны со статистикой посещений сайта,включая статистику по статьям. ',
	'texte_admin_effacer_toutes_stats' => 'Первая кнопка удаляет всю статистику о: посещениях, популярности и источниках переходов.',
	'texte_comment_lire_tableau' => 'Справа 
 показывается уровень 
  посещаемости статьи; черной линией отображается прогноз посещений (при условии 
 что сохранится 
  текущая динамика), и зеленым цветом - количество посещений за день. 
 Для более подробной информации 
 наведите мышку на интересующую Вас дату. ',
	'texte_signification' => 'Темные штрихи представляют накопленные записи (общее количество подразделов), светлые штрихи, представляют количество посещений для каждого раздела.',
	'titre_evolution_visite' => 'Уровень посещений',
	'titre_liens_entrants' => 'Источники переходов',
	'titre_page_statistiques' => 'По разделам',
	'titre_page_statistiques_visites' => 'История посещений',

	// V
	'visites_journalieres' => 'Количество посетителей (день)',
	'visites_mensuelles' => 'Количество посетителей (месяц)'
);

?>
